/*
    TUIO Simulator - part of the reacTIVision project
    http://reactivision.sourceforge.net/

    Copyright (c) 2005-2007 Martin Kaltenbrunner <mkalten@iua.upf.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

import java.awt.*;
import java.util.*;
import java.awt.geom.*;

public class TangibleType {

	public String name;
	public String shape;
	public String hexcolor;
	public String description;

	public Point2D center;
	public Color color;

	public TangibleType(String name, String shape, String hexcolor, String description) {

 			this.name = name;
			this.shape = shape;
			this.hexcolor = hexcolor;
			this.description = description;
	}

	public Shape getShape() {


		int R = Integer.parseInt(hexcolor.substring(0,2),16);
		int G = Integer.parseInt(hexcolor.substring(2,4),16);
		int B = Integer.parseInt(hexcolor.substring(4,6),16);
		color = new Color(R,G,B);

		Shape geom;
		if (shape.equals("circle")) {
			geom = new Ellipse2D.Float(0,0,40,40);
			center = new Point2D.Float(20,20);
		} else if (shape.equals("sphere")) {
			Area circle = new Area(new Ellipse2D.Float(0,0,40,40));
			Area hole = new Area(new Ellipse2D.Float(15,15,10,10));
			circle.subtract(hole);
			geom = circle;
			center = new Point2D.Float(20,20);
		} else if (shape.equals("square")) {
			geom = new Rectangle2D.Float(0,0,40,40);
			center = new Point2D.Float(20,20);
		} else if (shape.equals("roundsquare")) {
			geom = new RoundRectangle2D.Float(0,0,40,40,20,20);
			center = new Point2D.Float(20,20);
		} else if (shape.equals("triangle")) {
			GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD,2);
			float height = (float)(Math.sqrt(3)*40/2);
			path.moveTo(20f, 40-height);
			path.lineTo(40, 40);
			path.lineTo(0, 40);
			path.closePath();
			geom = path;
			center = new Point2D.Float(20f,40-height/2);
		} else if (shape.equals("star")) {
			float height = (float)(Math.sqrt(3)*40/2);
			GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD,2);
			path.moveTo(20, 0);
                        path.lineTo(28, 12);
                        path.lineTo(40, 20);
                        path.lineTo(28, 28);
                        path.lineTo(20, 40);
                        path.lineTo(0, 20);
                        path.lineTo(12, 12);
			path.closePath();

			AffineTransform  trans = AffineTransform.getRotateInstance(Math.PI/4,20.0,20.0);
			Shape shp = trans.createTransformedShape(path);

			Area area = new Area(path);
			area.add(new Area(shp));
			geom =area;

			center = new Point2D.Float(20,20);
		} else if (shape.equals("octagon")) {
			float height = (float)(Math.sqrt(3)*40/2);
			GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD,2);
			path.moveTo(10, 0);
                        path.lineTo(30, 0);
                        path.lineTo(40, 10);
                        path.lineTo(40, 30);
                        path.lineTo(30, 40);
                        path.lineTo(10, 40);
                        path.lineTo(0, 30);
                        path.lineTo(0, 10);
                        path.closePath();
                        geom = path;
			path.closePath();
			geom = path;
			center = new Point2D.Float(20,20);
		} else if (shape.equals("ellipse")) {
			geom = new Ellipse2D.Float(0,0,30,40);
			center = new Point2D.Float(15,20);
		} else if (shape.equals("cross")) {
			float height = (float)(Math.sqrt(3)*40/2);
			GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD,2);
			path.moveTo(10, 0);
                        path.lineTo(30, 0);
                        path.lineTo(30, 10);
                        path.lineTo(40, 10);
                        path.lineTo(40, 30);
                        path.lineTo(30, 30);
                        path.lineTo(30, 40);
                        path.lineTo(10, 40);
                        path.lineTo(10, 30);
                        path.lineTo(0, 30);
                        path.lineTo(0, 10);
			path.lineTo(10, 10);
 			path.closePath();
			geom = path;
			center = new Point2D.Float(20,20);
		} else if (shape.equals("hourglass")) {
			float height = (float)(Math.sqrt(3)*40/2);
			GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD,2);
			path.moveTo(20f, 40-height);
			path.lineTo(40, 40);
			path.lineTo(0, 40);
			path.closePath();
			GeneralPath path1 = new GeneralPath(GeneralPath.WIND_EVEN_ODD,2);
			path1.moveTo(0, 0);
			path1.lineTo(20f, height);
			path1.lineTo(40, 0);
			path1.closePath();
			path.append(path1,false);
			Area area = new Area(path);
			area.add(new Area(path1));
			geom =area;
			center = new Point2D.Float(20,20);
		} else if (shape.equals("pentagon")) {
			GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD,2);
			path.moveTo(20, 40);

			float x,y,a;
			for (int i=1;i<5;i++) {
				a = (float)((2*Math.PI/5)*i);
				x = (float)(20 + 20*Math.sin(a));
				y = (float)(20 + 20*Math.cos(a));
				path.lineTo(x, y);
			}
			path.closePath();
			geom = path;
			center = new Point2D.Float(20,20);
		} else if (shape.equals("hexagon")) {
			GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD,2);
			path.moveTo(20, 40);

			float x,y,a;
			for (int i=1;i<6;i++) {
				a = (float)((2*Math.PI/6)*i);
				x = (float)(20 + 20*Math.sin(a));
				y = (float)(20 + 20*Math.cos(a));
				path.lineTo(x, y);
			}
			path.closePath();
			geom = path;
			center = new Point2D.Float(20,20);
		}  else {
			geom = new Ellipse2D.Float(0,0,40,40);
			center = new Point2D.Float(20,20);
		}

		return geom;
	}
}
